[PATCH v2 3/3] selftests/resctrl: Fix non-contiguous CBM check for Hygon

From: Xiaochen Shen

Date: Fri Dec 05 2025 - 04:26:48 EST


The resctrl selftest currently fails on Hygon CPUs that always supports
non-contiguous CBM, printing the error:

"# Hardware and kernel differ on non-contiguous CBM support!"

This occurs because the arch_supports_noncont_cat() function lacks
vendor detection for Hygon CPUs, preventing proper identification of
their non-contiguous CBM capability.

Fix this by adding Hygon vendor ID detection to
arch_supports_noncont_cat().

Signed-off-by: Xiaochen Shen <shenxiaochen@xxxxxxxxxxxxxx>
Reviewed-by: Reinette Chatre <reinette.chatre@xxxxxxxxx>
---
Maintainer note:
Even though this is a fix it is not a candidate for backport since it is
based on another patch series (x86/resctrl: Fix Platform QoS issues for
Hygon) which is in process of being added to resctrl.

tools/testing/selftests/resctrl/cat_test.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/tools/testing/selftests/resctrl/cat_test.c b/tools/testing/selftests/resctrl/cat_test.c
index 94cfdba5308d..59a0f80fdc5a 100644
--- a/tools/testing/selftests/resctrl/cat_test.c
+++ b/tools/testing/selftests/resctrl/cat_test.c
@@ -290,8 +290,8 @@ static int cat_run_test(const struct resctrl_test *test, const struct user_param

static bool arch_supports_noncont_cat(const struct resctrl_test *test)
{
- /* AMD always supports non-contiguous CBM. */
- if (get_vendor() == ARCH_AMD)
+ /* AMD and Hygon always supports non-contiguous CBM. */
+ if (get_vendor() == ARCH_AMD || get_vendor() == ARCH_HYGON)
return true;

#if defined(__i386__) || defined(__x86_64__) /* arch */
--
2.47.3